@@ -10,8 +10,7 @@
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU Affero General Public License as        *
- *   published by the Free Software Foundation, either version 3 of the    *
- *   License, or (at your option) any later version.                       *
+ *   published by the Free Software Foundation, version 3 of the License.  *
  *                                                                         *
  ***************************************************************************/
 
@@ -33,11 +32,9 @@
 
 #include <QTextEdit>
 
-/*
 #include <Qt>
 #include <QShortcut>
 #include <QKeySequence>
-*/
 
 #if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
 #include <QRegularExpression>
@@ -115,47 +112,54 @@ AllSpaceConstraintsForm::AllSpaceConstraintsForm(QWidget* parent): QDialog(paren
 
 	connect(weightsPushButton, &QPushButton::clicked, this, &AllSpaceConstraintsForm::changeWeights);
 
-	/*
-	QShortcut* modifyShortcut=new QShortcut(QKeySequence(Qt::Key_M), this);
-	connect(modifyShortcut, &QShortcut::activated, [=]{modifyConstraintPushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		modifyConstraintPushButton->setToolTip(QString("M"));
-	//
-	QShortcut* removeShortcut=new QShortcut(QKeySequence::Delete, this);
-	connect(removeShortcut, &QShortcut::activated, [=]{removeConstraintsPushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		removeConstraintsPushButton->setToolTip(QString("⌦"));
-	//
-	QShortcut* activateShortcut=new QShortcut(QKeySequence(Qt::Key_A), this);
-	connect(activateShortcut, &QShortcut::activated, [=]{activatePushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		activatePushButton->setToolTip(QString("A"));
-	//
-	QShortcut* deactivateShortcut=new QShortcut(QKeySequence(Qt::Key_D), this);
-	connect(deactivateShortcut, &QShortcut::activated, [=]{deactivatePushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		deactivatePushButton->setToolTip(QString("D"));
-	//
-	QShortcut* commentsShortcut=new QShortcut(QKeySequence(Qt::Key_C), this);
-	connect(commentsShortcut, &QShortcut::activated, [=]{commentsPushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		commentsPushButton->setToolTip(QString("C"));
-	//
-	QShortcut* upShortcut=new QShortcut(QKeySequence(Qt::Key_U), this);
-	connect(upShortcut, &QShortcut::activated, [=]{moveSpaceConstraintUpPushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		moveSpaceConstraintUpPushButton->setToolTip(QString("U"));
-	//
-	QShortcut* downShortcut=new QShortcut(QKeySequence(Qt::Key_J), this);
-	connect(downShortcut, &QShortcut::activated, [=]{moveSpaceConstraintDownPushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		moveSpaceConstraintDownPushButton->setToolTip(QString("J"));
-	//
-	QShortcut* weightsShortcut=new QShortcut(QKeySequence(Qt::Key_W), this);
-	connect(weightsShortcut, &QShortcut::activated, [=]{weightsPushButton->animateClick();});
-	if(SHOW_TOOL_TIPS)
-		weightsPushButton->setToolTip(QString("W"));
-	*/
+	if(SHORTCUT_M){
+		QShortcut* modifyShortcut=new QShortcut(QKeySequence(Qt::Key_M), this);
+		connect(modifyShortcut, &QShortcut::activated, [=]{modifyConstraintPushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	modifyConstraintPushButton->setToolTip(QString("M"));
+	}
+	if(SHORTCUT_DELETE){
+		QShortcut* removeShortcut=new QShortcut(QKeySequence::Delete, this);
+		connect(removeShortcut, &QShortcut::activated, [=]{removeConstraintsPushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	removeConstraintsPushButton->setToolTip(QString("⌦"));
+	}
+	if(SHORTCUT_A){
+		QShortcut* activateShortcut=new QShortcut(QKeySequence(Qt::Key_A), this);
+		connect(activateShortcut, &QShortcut::activated, [=]{activatePushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	activatePushButton->setToolTip(QString("A"));
+	}
+	if(SHORTCUT_D){
+		QShortcut* deactivateShortcut=new QShortcut(QKeySequence(Qt::Key_D), this);
+		connect(deactivateShortcut, &QShortcut::activated, [=]{deactivatePushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	deactivatePushButton->setToolTip(QString("D"));
+	}
+	if(SHORTCUT_C){
+		QShortcut* commentsShortcut=new QShortcut(QKeySequence(Qt::Key_C), this);
+		connect(commentsShortcut, &QShortcut::activated, [=]{commentsPushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	commentsPushButton->setToolTip(QString("C"));
+	}
+	if(SHORTCUT_U){
+		QShortcut* upShortcut=new QShortcut(QKeySequence(Qt::Key_U), this);
+		connect(upShortcut, &QShortcut::activated, [=]{moveSpaceConstraintUpPushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	moveSpaceConstraintUpPushButton->setToolTip(QString("U"));
+	}
+	if(SHORTCUT_J){
+		QShortcut* downShortcut=new QShortcut(QKeySequence(Qt::Key_J), this);
+		connect(downShortcut, &QShortcut::activated, [=]{moveSpaceConstraintDownPushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	moveSpaceConstraintDownPushButton->setToolTip(QString("J"));
+	}
+	if(SHORTCUT_W){
+		QShortcut* weightsShortcut=new QShortcut(QKeySequence(Qt::Key_W), this);
+		connect(weightsShortcut, &QShortcut::activated, [=]{weightsPushButton->animateClick();});
+		//if(SHOW_TOOL_TIPS)
+		//	weightsPushButton->setToolTip(QString("W"));
+	}
 
 	centerWidgetOnScreen(this);
 	restoreFETDialogGeometry(this);
